@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import json
 import logging
-from datetime import datetime
+from datetime import datetime, timedelta
 from pathlib import Path
 from typing import Any, Dict, List, Optional, cast
 
@@ -55,7 +55,6 @@ class Server(Base):
     power_enabled = Column(Boolean, nullable=False, server_default=true())
     tags_enabled = Column(Boolean, nullable=False, server_default=true())
     create_voice = Column(Boolean, nullable=False, server_default=false())
-    voice_category_xid = Column(BigInteger)
     games = relationship("Game", back_populates="server", uselist=True)
     channels = relationship("Channel", back_populates="server", uselist=True)
     teams = relationship("Team", back_populates="server", uselist=True)
@@ -343,6 +342,7 @@ class Game(Base):
             Game.size == size,
             Game.channel_xid == channel_xid,
             Game.system == system,
+            Game.message_xid != None,
         ]
         having_filters = [
             func.count(distinct(games_tags.c.tag_id)) == len(required_tag_ids),
@@ -393,10 +393,27 @@ class Game(Base):
             .all(),
         )
 
+    def is_expired(self) -> bool:
+        if (
+            self.status == "pending"
+            and self.expires_at
+            and datetime.utcnow() >= self.expires_at
+        ):
+            return True
+        return False
+
     @classmethod
     def voiced(cls, session: Session) -> List[Game]:
         return cast(
-            List[Game], session.query(Game).filter(Game.voice_channel_xid != None).all()
+            List[Game],
+            session.query(Game)
+            .filter(
+                and_(
+                    Game.voice_channel_xid != None,
+                    datetime.utcnow() - timedelta(minutes=10) >= Game.updated_at,
+                )
+            )
+            .all(),
         )
 
     def __repr__(self) -> str:
@@ -424,6 +441,7 @@ class Game(Base):
         }
 
     def to_embed(self, dm=False) -> discord.Embed:
+        prefix = self.server.prefix
         show_link = True if dm else self.server.links == "public"
         if self.status == "pending":
             remaining = int(self.size) - len(cast(List[User], self.users))
@@ -439,7 +457,12 @@ class Game(Base):
             if show_link:
                 description = f"Join your voice chat now: {self.voice_channel_invite}\n\n"
         if self.status == "pending":
-            description += "To join/leave this game, react with ✋/🚫."
+            description += (
+                "To **join this game**, react with ✋\n"
+                "If you need to drop, react with 🚫\n\n"
+                "_A SpellTable link will be created when all players have joined._\n\n"
+                f"Looking for more players to join you? Just run `{prefix}lfg` again.\n"
+            )
         elif self.system == "spelltable":
             if show_link:
                 description += (
